``DustPy`` Documentation
=========================================

| ``DustPy`` is a Python package to simulate the evolution of dust in protoplanetary disks.

| This documentation is for ``DustPy v1.0.1``.

| ``DustPy`` simulates the radial evolution of gas and dust in a protoplanetary disk, involving viscous evolution of the gas disk, advection and diffusion of the dust disk, as well as dust growth by solving the Smoluchowski equation.

| ``DustPy`` can be installed via the Python Package Index
| ``pip install dustpy``

| ``DustPy`` requires a Python3 distribution and a Fortran compiler.

| ``DustPy`` is based on the ``Simframe`` framework for scientific simulation (`Stammler & Birnstiel 2022 <https://joss.theoj.org/papers/10.21105/joss.03882>`_).
| Please have a look at the `Simframe Documentation <https://simframe.rtfd.io>`_ for details of its usage.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   1_basics
   2_simple_customization
   3_advanced_customization
   4_standard_model
   5_dust_coagulation
   6_dust_evolution
   7_gas_evolution
   test_analytical_coagulation_kernels
   test_gas_evolution
   example_ice_lines
   example_planetary_gaps
   example_planetesimal_formation
   A_citation
   B_publications
   C_contrib_bug_feature
   D_discussions
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
